package VMOMI::CustomizationSysprepRebootOption;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
